<?php
/**
 * VW Driving School Theme Customizer
 *
 * @package VW Driving School
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_driving_school_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_driving_school_custom_controls' );

function vw_driving_school_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_driving_school_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-driving-school' ),
	    'description' => __( 'Description of what this panel does.', 'vw-driving-school' ),
	) );

	$wp_customize->add_section( 'vw_driving_school_left_right', array(
    	'title'      => __( 'General Settings', 'vw-driving-school' ),
		'priority'   => 30,
		'panel' => 'vw_driving_school_panel_id'
	) );

	$wp_customize->add_setting('vw_driving_school_width_option',array(
        'default' => __('Full Width','vw-driving-school'),
        'sanitize_callback' => 'vw_driving_school_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Driving_School_Image_Radio_Control($wp_customize, 'vw_driving_school_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-driving-school'),
        'description' => __('Here you can change the width layout of Website.','vw-driving-school'),
        'section' => 'vw_driving_school_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/assets/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/assets/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/assets/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_driving_school_theme_options',array(
        'default' => __('Right Sidebar','vw-driving-school'),
        'sanitize_callback' => 'vw_driving_school_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_driving_school_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-driving-school'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-driving-school'),
        'section' => 'vw_driving_school_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-driving-school'),
            'Right Sidebar' => __('Right Sidebar','vw-driving-school'),
            'One Column' => __('One Column','vw-driving-school'),
            'Three Columns' => __('Three Columns','vw-driving-school'),
            'Four Columns' => __('Four Columns','vw-driving-school'),
            'Grid Layout' => __('Grid Layout','vw-driving-school')
        ),
	));

	$wp_customize->add_setting('vw_driving_school_page_layout',array(
        'default' => __('One Column','vw-driving-school'),
        'sanitize_callback' => 'vw_driving_school_sanitize_choices'
	));
	$wp_customize->add_control('vw_driving_school_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-driving-school'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-driving-school'),
        'section' => 'vw_driving_school_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-driving-school'),
            'Right Sidebar' => __('Right Sidebar','vw-driving-school'),
            'One Column' => __('One Column','vw-driving-school')
        ),
	) );

	//Topbar
	$wp_customize->add_section( 'vw_driving_school_topbar', array(
    	'title'      => __( 'Topbar Settings', 'vw-driving-school' ),
		'priority'   => 30,
		'panel' => 'vw_driving_school_panel_id'
	) );

	$wp_customize->add_setting('vw_driving_school_discount_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_driving_school_discount_text',array(
		'label'	=> __('Add Discount Text','vw-driving-school'),
		'input_attrs' => array(
            'placeholder' => __( 'Lorem Ipsum is simply dummy text of the printing.', 'vw-driving-school' ),
        ),
		'section'=> 'vw_driving_school_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_driving_school_booking_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_driving_school_booking_text',array(
		'label'	=> __('Add Button Text','vw-driving-school'),
		'input_attrs' => array(
            'placeholder' => __( 'BOOK A CLASS', 'vw-driving-school' ),
        ),
		'section'=> 'vw_driving_school_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_driving_school_booking_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('vw_driving_school_booking_link',array(
		'label'	=> __('Add Button Link','vw-driving-school'),
		'input_attrs' => array(
            'placeholder' => __( 'http://www.example.com', 'vw-driving-school' ),
        ),
		'section'=> 'vw_driving_school_topbar',		
		'type'=> 'url'
	));
    
	//Slider
	$wp_customize->add_section( 'vw_driving_school_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'vw-driving-school' ),
		'priority'   => null,
		'panel' => 'vw_driving_school_panel_id'
	) );

	$wp_customize->add_setting( 'vw_driving_school_slider_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_driving_school_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Driving_School_Toggle_Switch_Custom_Control( $wp_customize, 'vw_driving_school_slider_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Slider','vw-driving-school' ),
          'section' => 'vw_driving_school_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'vw_driving_school_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_driving_school_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_driving_school_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'vw-driving-school' ),
			'description' => __('Slider image size (1500 x 590)','vw-driving-school'),
			'section'  => 'vw_driving_school_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('vw_driving_school_slider_content_option',array(
        'default' => __('Left','vw-driving-school'),
        'sanitize_callback' => 'vw_driving_school_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Driving_School_Image_Radio_Control($wp_customize, 'vw_driving_school_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-driving-school'),
        'section' => 'vw_driving_school_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/assets/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_driving_school_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_driving_school_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-driving-school' ),
		'section'     => 'vw_driving_school_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_driving_school_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('vw_driving_school_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_driving_school_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_driving_school_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-driving-school' ),
	'section'     => 'vw_driving_school_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_driving_school_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','vw-driving-school'),
      '0.1' =>  esc_attr('0.1','vw-driving-school'),
      '0.2' =>  esc_attr('0.2','vw-driving-school'),
      '0.3' =>  esc_attr('0.3','vw-driving-school'),
      '0.4' =>  esc_attr('0.4','vw-driving-school'),
      '0.5' =>  esc_attr('0.5','vw-driving-school'),
      '0.6' =>  esc_attr('0.6','vw-driving-school'),
      '0.7' =>  esc_attr('0.7','vw-driving-school'),
      '0.8' =>  esc_attr('0.8','vw-driving-school'),
      '0.9' =>  esc_attr('0.9','vw-driving-school')
	),
	));

	//Contact Section
	$wp_customize->add_section( 'vw_driving_school_contact_section' , array(
    	'title'      => __( 'Contact us', 'vw-driving-school' ),
		'priority'   => null,
		'panel' => 'vw_driving_school_panel_id'
	) );

	$wp_customize->add_setting('vw_driving_school_phone',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_driving_school_phone',array(
		'label'	=> __('Add Phone no.','vw-driving-school'),
		'input_attrs' => array(
            'placeholder' => __( '+00 123 456 7890', 'vw-driving-school' ),
        ),
		'section'=> 'vw_driving_school_contact_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_driving_school_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_driving_school_email_address',array(
		'label'	=> __('Add Email Address','vw-driving-school'),
		'input_attrs' => array(
            'placeholder' => __( 'support@example.com', 'vw-driving-school' ),
        ),
		'section'=> 'vw_driving_school_contact_section',
		'type'=> 'text'
	));

	//About Section
	$wp_customize->add_section( 'vw_driving_school_about_section' , array(
    	'title'      => __( 'About us', 'vw-driving-school' ),
		'priority'   => null,
		'panel' => 'vw_driving_school_panel_id'
	) );

	$wp_customize->add_setting( 'vw_driving_school_about_page', array(
		'default'           => '',
		'sanitize_callback' => 'vw_driving_school_sanitize_dropdown_pages'
	) );
	$wp_customize->add_control( 'vw_driving_school_about_page', array(
		'label'    => __( 'About Page', 'vw-driving-school' ),
		'description' => __('Image size (1500 x 590)','vw-driving-school'),
		'section'  => 'vw_driving_school_about_section',
		'type'     => 'dropdown-pages'
	) );

	//About excerpt
	$wp_customize->add_setting( 'vw_driving_school_about_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_driving_school_about_excerpt_number', array(
		'label'       => esc_html__( 'About Excerpt length','vw-driving-school' ),
		'section'     => 'vw_driving_school_about_section',
		'type'        => 'range',
		'settings'    => 'vw_driving_school_about_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_section('vw_driving_school_blog_post',array(
		'title'	=> __('Blog Post Settings','vw-driving-school'),
		'panel' => 'vw_driving_school_panel_id',
	));	

	$wp_customize->add_setting( 'vw_driving_school_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_driving_school_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Driving_School_Toggle_Switch_Custom_Control( $wp_customize, 'vw_driving_school_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-driving-school' ),
        'section' => 'vw_driving_school_blog_post'
    )));

    $wp_customize->add_setting( 'vw_driving_school_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_driving_school_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Driving_School_Toggle_Switch_Custom_Control( $wp_customize, 'vw_driving_school_toggle_author',array(
		'label' => esc_html__( 'Author','vw-driving-school' ),
		'section' => 'vw_driving_school_blog_post'
    )));

    $wp_customize->add_setting( 'vw_driving_school_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_driving_school_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Driving_School_Toggle_Switch_Custom_Control( $wp_customize, 'vw_driving_school_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-driving-school' ),
		'section' => 'vw_driving_school_blog_post'
    )));

    $wp_customize->add_setting( 'vw_driving_school_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_driving_school_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-driving-school' ),
		'section'     => 'vw_driving_school_blog_post',
		'type'        => 'range',
		'settings'    => 'vw_driving_school_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Content Craetion
	$wp_customize->add_section( 'vw_driving_school_content_section' , array(
    	'title' => __( 'Customize Home Page', 'vw-driving-school' ),
		'priority' => null,
		'panel' => 'vw_driving_school_panel_id'
	) );

	$wp_customize->add_setting('vw_driving_school_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Driving_School_Content_Creation( $wp_customize, 'vw_driving_school_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-driving-school' ),
		),
		'section' => 'vw_driving_school_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-driving-school' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('vw_driving_school_footer',array(
		'title'	=> __('Footer','vw-driving-school'),
		'description'=> __('This section will appear in the footer','vw-driving-school'),
		'panel' => 'vw_driving_school_panel_id',
	));	
	
	$wp_customize->add_setting('vw_driving_school_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_driving_school_footer_text',array(
		'label'	=> __('Copyright Text','vw-driving-school'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2018......', 'vw-driving-school' ),
        ),
		'section'=> 'vw_driving_school_footer',
		'setting'=> 'vw_driving_school_footer_text',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_driving_school_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_driving_school_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Driving_School_Toggle_Switch_Custom_Control( $wp_customize, 'vw_driving_school_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-driving-school' ),
      	'section' => 'vw_driving_school_footer'
    )));

	$wp_customize->add_setting('vw_driving_school_scroll_top_alignment',array(
        'default' => __('Right','vw-driving-school'),
        'sanitize_callback' => 'vw_driving_school_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Driving_School_Image_Radio_Control($wp_customize, 'vw_driving_school_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-driving-school'),
        'section' => 'vw_driving_school_footer',
        'settings' => 'vw_driving_school_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/layout2.png',
            'Right' => get_template_directory_uri().'/assets/images/layout3.png'
    ))));	
}

add_action( 'customize_register', 'vw_driving_school_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Driving_School_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Driving_School_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Driving_School_Customize_Section_Pro($manager,'example_1',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DRIVING SCHOOL PRO', 'vw-driving-school' ),
			'pro_text' => esc_html__( 'GO PRO', 'vw-driving-school' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/driving-school-wordpress-theme/'),
		)));

		// Register sections.
		$manager->add_section(new VW_Driving_School_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'vw-driving-school' ),
			'pro_text' => esc_html__( 'DOCS', 'vw-driving-school' ),
			'pro_url'  => admin_url( 'themes.php?page=vw_driving_school_guide' )
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-driving-school-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-driving-school-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Driving_School_Customize::get_instance();